@@ -1,11 +1,12 @@
 var indexSectionsWithContent =
 {
-  0: "acgijsv",
+  0: "acgijmpqsv",
   1: "j",
-  2: "j",
-  3: "acgs",
-  4: "iv",
-  5: "j"
+  2: "jq",
+  3: "acgmps",
+  4: "ijv",
+  5: "j",
+  6: "j"
 };
 
 var indexSectionNames =
@@ -15,7 +16,8 @@ var indexSectionNames =
   2: "namespaces",
   3: "functions",
   4: "variables",
-  5: "pages"
+  5: "groups",
+  6: "pages"
 };
 
 var indexSectionLabels =
@@ -25,6 +27,7 @@ var indexSectionLabels =
   2: "Namespaces",
   3: "Functions",
   4: "Variables",
-  5: "Pages"
+  5: "Modules",
+  6: "Pages"
 };
 
